@@ -10,8 +10,8 @@ sub connect {
     
     $self->include_model(
         MyModel1 => [
-            'table1',
-            'table2'
+            $self->table1,
+            $self->table2
         ]
     );
 }
